Codebase list libcryptx-perl / 9490def debian / patches / 001_fix-typos.patch
9490def

Tree @9490def (Download .tar.gz)

001_fix-typos.patch @9490defraw · history · blame

  1
  2
  3
  4
  5
  6
  7
  8
  9
 10
 11
 12
 13
 14
 15
 16
 17
 18
 19
 20
 21
 22
 23
 24
 25
 26
 27
 28
 29
 30
 31
 32
 33
 34
 35
 36
 37
 38
 39
 40
 41
 42
 43
 44
 45
 46
 47
 48
 49
 50
 51
 52
 53
 54
 55
 56
 57
 58
 59
 60
 61
 62
 63
 64
 65
 66
 67
 68
 69
 70
 71
 72
 73
 74
 75
 76
 77
 78
 79
 80
 81
 82
 83
 84
 85
 86
 87
 88
 89
 90
 91
 92
 93
 94
 95
 96
 97
 98
 99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
Description: Fix typos in POD
Author: Lucas Kanashiro <kanashiro@debian.org>
Last-Updated: 2017-06-25
Forwarded: https://github.com/DCIT/perl-CryptX/pull/40
Bug: https://github.com/DCIT/perl-CryptX/pull/40

--- a/lib/Crypt/Cipher/AES.pm
+++ b/lib/Crypt/Cipher/AES.pm
@@ -21,7 +21,7 @@ sub default_rounds { Crypt::Cipher::defa
 
 =head1 NAME
 
-Crypt::Cipher::AES - Symetric cipher AES (aka Rijndael), key size: 128/192/256 bits (Crypt::CBC compliant)
+Crypt::Cipher::AES - Symmetric cipher AES (aka Rijndael), key size: 128/192/256 bits (Crypt::CBC compliant)
 
 =head1 SYNOPSIS
 
@@ -118,4 +118,4 @@ L<Crypt::Mode::CBC|Crypt::Mode::CBC>, L<
 
 =cut
 
-__END__
\ No newline at end of file
+__END__
--- a/lib/Crypt/Cipher/Anubis.pm
+++ b/lib/Crypt/Cipher/Anubis.pm
@@ -21,7 +21,7 @@ sub default_rounds { Crypt::Cipher::defa
 
 =head1 NAME
 
-Crypt::Cipher::Anubis - Symetric cipher Anubis, key size: 128-320 bits (Crypt::CBC compliant)
+Crypt::Cipher::Anubis - Symmetric cipher Anubis, key size: 128-320 bits (Crypt::CBC compliant)
 
 =head1 SYNOPSIS
 
@@ -118,4 +118,4 @@ L<Crypt::Mode::CBC|Crypt::Mode::CBC>, L<
 
 =cut
 
-__END__
\ No newline at end of file
+__END__
--- a/lib/Crypt/Cipher/Blowfish.pm
+++ b/lib/Crypt/Cipher/Blowfish.pm
@@ -21,7 +21,7 @@ sub default_rounds { Crypt::Cipher::defa
 
 =head1 NAME
 
-Crypt::Cipher::Blowfish - Symetric cipher Blowfish, key size: 64-448 bits (Crypt::CBC compliant)
+Crypt::Cipher::Blowfish - Symmetric cipher Blowfish, key size: 64-448 bits (Crypt::CBC compliant)
 
 =head1 SYNOPSIS
 
@@ -118,4 +118,4 @@ L<Crypt::Mode::CBC|Crypt::Mode::CBC>, L<
 
 =cut
 
-__END__
\ No newline at end of file
+__END__
--- a/lib/Crypt/Cipher/CAST5.pm
+++ b/lib/Crypt/Cipher/CAST5.pm
@@ -21,7 +21,7 @@ sub default_rounds { Crypt::Cipher::defa
 
 =head1 NAME
 
-Crypt::Cipher::CAST5 - Symetric cipher CAST5 (aka CAST-128), key size: 40-128 bits (Crypt::CBC compliant)
+Crypt::Cipher::CAST5 - Symmetric cipher CAST5 (aka CAST-128), key size: 40-128 bits (Crypt::CBC compliant)
 
 =head1 SYNOPSIS
 
@@ -118,4 +118,4 @@ L<Crypt::Mode::CBC|Crypt::Mode::CBC>, L<
 
 =cut
 
-__END__
\ No newline at end of file
+__END__
--- a/lib/Crypt/Cipher/Camellia.pm
+++ b/lib/Crypt/Cipher/Camellia.pm
@@ -21,7 +21,7 @@ sub default_rounds { Crypt::Cipher::defa
 
 =head1 NAME
 
-Crypt::Cipher::Camellia - Symetric cipher Camellia, key size: 128/192/256 bits (Crypt::CBC compliant)
+Crypt::Cipher::Camellia - Symmetric cipher Camellia, key size: 128/192/256 bits (Crypt::CBC compliant)
 
 =head1 SYNOPSIS
 
@@ -118,4 +118,4 @@ L<Crypt::Mode::CBC|Crypt::Mode::CBC>, L<
 
 =cut
 
-__END__
\ No newline at end of file
+__END__
--- a/lib/Crypt/Cipher/DES.pm
+++ b/lib/Crypt/Cipher/DES.pm
@@ -21,7 +21,7 @@ sub default_rounds { Crypt::Cipher::defa
 
 =head1 NAME
 
-Crypt::Cipher::DES - Symetric cipher DES, key size: 64[56] bits (Crypt::CBC compliant)
+Crypt::Cipher::DES - Symmetric cipher DES, key size: 64[56] bits (Crypt::CBC compliant)
 
 =head1 SYNOPSIS
 
@@ -118,4 +118,4 @@ L<Crypt::Mode::CBC|Crypt::Mode::CBC>, L<
 
 =cut
 
-__END__
\ No newline at end of file
+__END__
--- a/lib/Crypt/Cipher/DES_EDE.pm
+++ b/lib/Crypt/Cipher/DES_EDE.pm
@@ -21,7 +21,7 @@ sub default_rounds { Crypt::Cipher::defa
 
 =head1 NAME
 
-Crypt::Cipher::DES_EDE - Symetric cipher DES_EDE (aka Tripple-DES, 3DES), key size: 192[168] bits (Crypt::CBC compliant)
+Crypt::Cipher::DES_EDE - Symmetric cipher DES_EDE (aka Tripple-DES, 3DES), key size: 192[168] bits (Crypt::CBC compliant)
 
 =head1 SYNOPSIS
 
@@ -118,4 +118,4 @@ L<Crypt::Mode::CBC|Crypt::Mode::CBC>, L<
 
 =cut
 
-__END__
\ No newline at end of file
+__END__
--- a/lib/Crypt/Cipher/KASUMI.pm
+++ b/lib/Crypt/Cipher/KASUMI.pm
@@ -21,7 +21,7 @@ sub default_rounds { Crypt::Cipher::defa
 
 =head1 NAME
 
-Crypt::Cipher::KASUMI - Symetric cipher KASUMI, key size: 128 bits (Crypt::CBC compliant)
+Crypt::Cipher::KASUMI - Symmetric cipher KASUMI, key size: 128 bits (Crypt::CBC compliant)
 
 =head1 SYNOPSIS
 
@@ -118,4 +118,4 @@ L<Crypt::Mode::CBC|Crypt::Mode::CBC>, L<
 
 =cut
 
-__END__
\ No newline at end of file
+__END__
--- a/lib/Crypt/Cipher/Khazad.pm
+++ b/lib/Crypt/Cipher/Khazad.pm
@@ -21,7 +21,7 @@ sub default_rounds { Crypt::Cipher::defa
 
 =head1 NAME
 
-Crypt::Cipher::Khazad - Symetric cipher Khazad, key size: 128 bits (Crypt::CBC compliant)
+Crypt::Cipher::Khazad - Symmetric cipher Khazad, key size: 128 bits (Crypt::CBC compliant)
 
 =head1 SYNOPSIS
 
@@ -118,4 +118,4 @@ L<Crypt::Mode::CBC|Crypt::Mode::CBC>, L<
 
 =cut
 
-__END__
\ No newline at end of file
+__END__
--- a/lib/Crypt/Cipher/MULTI2.pm
+++ b/lib/Crypt/Cipher/MULTI2.pm
@@ -21,7 +21,7 @@ sub default_rounds { Crypt::Cipher::defa
 
 =head1 NAME
 
-Crypt::Cipher::MULTI2 - Symetric cipher MULTI2, key size: 320 bits (Crypt::CBC compliant)
+Crypt::Cipher::MULTI2 - Symmetric cipher MULTI2, key size: 320 bits (Crypt::CBC compliant)
 
 =head1 SYNOPSIS
 
@@ -118,4 +118,4 @@ L<Crypt::Mode::CBC|Crypt::Mode::CBC>, L<
 
 =cut
 
-__END__
\ No newline at end of file
+__END__
--- a/lib/Crypt/Cipher/Noekeon.pm
+++ b/lib/Crypt/Cipher/Noekeon.pm
@@ -21,7 +21,7 @@ sub default_rounds { Crypt::Cipher::defa
 
 =head1 NAME
 
-Crypt::Cipher::Noekeon - Symetric cipher Noekeon, key size: 128 bits (Crypt::CBC compliant)
+Crypt::Cipher::Noekeon - Symmetric cipher Noekeon, key size: 128 bits (Crypt::CBC compliant)
 
 =head1 SYNOPSIS
 
@@ -118,4 +118,4 @@ L<Crypt::Mode::CBC|Crypt::Mode::CBC>, L<
 
 =cut
 
-__END__
\ No newline at end of file
+__END__
--- a/lib/Crypt/Cipher/RC2.pm
+++ b/lib/Crypt/Cipher/RC2.pm
@@ -21,7 +21,7 @@ sub default_rounds { Crypt::Cipher::defa
 
 =head1 NAME
 
-Crypt::Cipher::RC2 - Symetric cipher RC2, key size: 40-1024 bits (Crypt::CBC compliant)
+Crypt::Cipher::RC2 - Symmetric cipher RC2, key size: 40-1024 bits (Crypt::CBC compliant)
 
 =head1 SYNOPSIS
 
@@ -118,4 +118,4 @@ L<Crypt::Mode::CBC|Crypt::Mode::CBC>, L<
 
 =cut
 
-__END__
\ No newline at end of file
+__END__
--- a/lib/Crypt/Cipher/RC5.pm
+++ b/lib/Crypt/Cipher/RC5.pm
@@ -21,7 +21,7 @@ sub default_rounds { Crypt::Cipher::defa
 
 =head1 NAME
 
-Crypt::Cipher::RC5 - Symetric cipher RC5, key size: 64-1024 bits (Crypt::CBC compliant)
+Crypt::Cipher::RC5 - Symmetric cipher RC5, key size: 64-1024 bits (Crypt::CBC compliant)
 
 =head1 SYNOPSIS
 
@@ -118,4 +118,4 @@ L<Crypt::Mode::CBC|Crypt::Mode::CBC>, L<
 
 =cut
 
-__END__
\ No newline at end of file
+__END__
--- a/lib/Crypt/Cipher/RC6.pm
+++ b/lib/Crypt/Cipher/RC6.pm
@@ -21,7 +21,7 @@ sub default_rounds { Crypt::Cipher::defa
 
 =head1 NAME
 
-Crypt::Cipher::RC6 - Symetric cipher RC6, key size: 64-1024 bits (Crypt::CBC compliant)
+Crypt::Cipher::RC6 - Symmetric cipher RC6, key size: 64-1024 bits (Crypt::CBC compliant)
 
 =head1 SYNOPSIS
 
@@ -118,4 +118,4 @@ L<Crypt::Mode::CBC|Crypt::Mode::CBC>, L<
 
 =cut
 
-__END__
\ No newline at end of file
+__END__
--- a/lib/Crypt/Cipher/SAFERP.pm
+++ b/lib/Crypt/Cipher/SAFERP.pm
@@ -21,7 +21,7 @@ sub default_rounds { Crypt::Cipher::defa
 
 =head1 NAME
 
-Crypt::Cipher::SAFERP - Symetric cipher SAFER+, key size: 128/192/256 bits (Crypt::CBC compliant)
+Crypt::Cipher::SAFERP - Symmetric cipher SAFER+, key size: 128/192/256 bits (Crypt::CBC compliant)
 
 =head1 SYNOPSIS
 
@@ -118,4 +118,4 @@ L<Crypt::Mode::CBC|Crypt::Mode::CBC>, L<
 
 =cut
 
-__END__
\ No newline at end of file
+__END__
--- a/lib/Crypt/Cipher/SAFER_K128.pm
+++ b/lib/Crypt/Cipher/SAFER_K128.pm
@@ -21,7 +21,7 @@ sub default_rounds { Crypt::Cipher::defa
 
 =head1 NAME
 
-Crypt::Cipher::SAFER_K128 - Symetric cipher SAFER_K128, key size: 128 bits (Crypt::CBC compliant)
+Crypt::Cipher::SAFER_K128 - Symmetric cipher SAFER_K128, key size: 128 bits (Crypt::CBC compliant)
 
 =head1 SYNOPSIS
 
@@ -118,4 +118,4 @@ L<Crypt::Mode::CBC|Crypt::Mode::CBC>, L<
 
 =cut
 
-__END__
\ No newline at end of file
+__END__
--- a/lib/Crypt/Cipher/SAFER_K64.pm
+++ b/lib/Crypt/Cipher/SAFER_K64.pm
@@ -21,7 +21,7 @@ sub default_rounds { Crypt::Cipher::defa
 
 =head1 NAME
 
-Crypt::Cipher::SAFER_K64 - Symetric cipher SAFER_K64, key size: 64 bits (Crypt::CBC compliant)
+Crypt::Cipher::SAFER_K64 - Symmetric cipher SAFER_K64, key size: 64 bits (Crypt::CBC compliant)
 
 =head1 SYNOPSIS
 
@@ -118,4 +118,4 @@ L<Crypt::Mode::CBC|Crypt::Mode::CBC>, L<
 
 =cut
 
-__END__
\ No newline at end of file
+__END__
--- a/lib/Crypt/Cipher/SAFER_SK128.pm
+++ b/lib/Crypt/Cipher/SAFER_SK128.pm
@@ -21,7 +21,7 @@ sub default_rounds { Crypt::Cipher::defa
 
 =head1 NAME
 
-Crypt::Cipher::SAFER_SK128 - Symetric cipher SAFER_SK128, key size: 128 bits (Crypt::CBC compliant)
+Crypt::Cipher::SAFER_SK128 - Symmetric cipher SAFER_SK128, key size: 128 bits (Crypt::CBC compliant)
 
 =head1 SYNOPSIS
 
@@ -118,4 +118,4 @@ L<Crypt::Mode::CBC|Crypt::Mode::CBC>, L<
 
 =cut
 
-__END__
\ No newline at end of file
+__END__
--- a/lib/Crypt/Cipher/SAFER_SK64.pm
+++ b/lib/Crypt/Cipher/SAFER_SK64.pm
@@ -21,7 +21,7 @@ sub default_rounds { Crypt::Cipher::defa
 
 =head1 NAME
 
-Crypt::Cipher::SAFER_SK64 - Symetric cipher SAFER_SK64, key size: 64 bits (Crypt::CBC compliant)
+Crypt::Cipher::SAFER_SK64 - Symmetric cipher SAFER_SK64, key size: 64 bits (Crypt::CBC compliant)
 
 =head1 SYNOPSIS
 
@@ -118,4 +118,4 @@ L<Crypt::Mode::CBC|Crypt::Mode::CBC>, L<
 
 =cut
 
-__END__
\ No newline at end of file
+__END__
--- a/lib/Crypt/Cipher/SEED.pm
+++ b/lib/Crypt/Cipher/SEED.pm
@@ -21,7 +21,7 @@ sub default_rounds { Crypt::Cipher::defa
 
 =head1 NAME
 
-Crypt::Cipher::SEED - Symetric cipher SEED, key size: 128 bits (Crypt::CBC compliant)
+Crypt::Cipher::SEED - Symmetric cipher SEED, key size: 128 bits (Crypt::CBC compliant)
 
 =head1 SYNOPSIS
 
@@ -118,4 +118,4 @@ L<Crypt::Mode::CBC|Crypt::Mode::CBC>, L<
 
 =cut
 
-__END__
\ No newline at end of file
+__END__
--- a/lib/Crypt/Cipher/Skipjack.pm
+++ b/lib/Crypt/Cipher/Skipjack.pm
@@ -21,7 +21,7 @@ sub default_rounds { Crypt::Cipher::defa
 
 =head1 NAME
 
-Crypt::Cipher::Skipjack - Symetric cipher Skipjack, key size: 80 bits (Crypt::CBC compliant)
+Crypt::Cipher::Skipjack - Symmetric cipher Skipjack, key size: 80 bits (Crypt::CBC compliant)
 
 =head1 SYNOPSIS
 
@@ -118,4 +118,4 @@ L<Crypt::Mode::CBC|Crypt::Mode::CBC>, L<
 
 =cut
 
-__END__
\ No newline at end of file
+__END__
--- a/lib/Crypt/Cipher/Twofish.pm
+++ b/lib/Crypt/Cipher/Twofish.pm
@@ -21,7 +21,7 @@ sub default_rounds { Crypt::Cipher::defa
 
 =head1 NAME
 
-Crypt::Cipher::Twofish - Symetric cipher Twofish, key size: 128/192/256 bits (Crypt::CBC compliant)
+Crypt::Cipher::Twofish - Symmetric cipher Twofish, key size: 128/192/256 bits (Crypt::CBC compliant)
 
 =head1 SYNOPSIS
 
@@ -118,4 +118,4 @@ L<Crypt::Mode::CBC|Crypt::Mode::CBC>, L<
 
 =cut
 
-__END__
\ No newline at end of file
+__END__
--- a/lib/Crypt/Cipher/XTEA.pm
+++ b/lib/Crypt/Cipher/XTEA.pm
@@ -21,7 +21,7 @@ sub default_rounds { Crypt::Cipher::defa
 
 =head1 NAME
 
-Crypt::Cipher::XTEA - Symetric cipher XTEA, key size: 128 bits (Crypt::CBC compliant)
+Crypt::Cipher::XTEA - Symmetric cipher XTEA, key size: 128 bits (Crypt::CBC compliant)
 
 =head1 SYNOPSIS
 
@@ -118,4 +118,4 @@ L<Crypt::Mode::CBC|Crypt::Mode::CBC>, L<
 
 =cut
 
-__END__
\ No newline at end of file
+__END__
--- a/lib/Crypt/Digest.pm
+++ b/lib/Crypt/Digest.pm
@@ -176,7 +176,7 @@ Or all of them at once:
 
 =head1 FUNCTIONS
 
-Please note that all functions take as its first argument the algoritm name, supported values are:
+Please note that all functions take as its first argument the algorithm name, supported values are:
 
  'CHAES', 'MD2', 'MD4', 'MD5', 'RIPEMD128', 'RIPEMD160',
  'RIPEMD256', 'RIPEMD320', 'SHA1', 'SHA224', 'SHA256',
@@ -374,4 +374,4 @@ Returns the digest encoded as a Base64 U
 
 =cut
 
-__END__
\ No newline at end of file
+__END__
--- a/lib/Crypt/PK/ECC.pm
+++ b/lib/Crypt/PK/ECC.pm
@@ -1029,7 +1029,7 @@ Import raw public/private key - can load
  my $public_der = $pk->export_key_der('public');
 
 Since CryptX-0.36 C<export_key_der> can also export keys in a format
-that does not explicitely contain curve parameters but only curve OID.
+that does not explicitly contain curve parameters but only curve OID.
 
  my $private_der = $pk->export_key_der('private_short');
  #or
@@ -1042,7 +1042,7 @@ that does not explicitely contain curve
  my $public_pem = $pk->export_key_pem('public');
 
 Since CryptX-0.36 C<export_key_pem> can also export keys in a format
-that does not explicitely contain curve parameters but only curve OID.
+that does not explicitly contain curve parameters but only curve OID.
 
  my $private_pem = $pk->export_key_pem('private_short');
  #or
--- a/lib/Crypt/Cipher/IDEA.pm
+++ b/lib/Crypt/Cipher/IDEA.pm
@@ -21,7 +21,7 @@ sub default_rounds { Crypt::Cipher::defa
 
 =head1 NAME
 
-Crypt::Cipher::IDEA - Symetric cipher IDEA, key size: 128 bits (Crypt::CBC compliant)
+Crypt::Cipher::IDEA - Symmetric cipher IDEA, key size: 128 bits (Crypt::CBC compliant)
 
 =head1 SYNOPSIS
 
@@ -118,4 +118,4 @@ L<Crypt::Mode::CBC|Crypt::Mode::CBC>, L<
 
 =cut
 
-__END__
\ No newline at end of file
+__END__
--- a/lib/Crypt/Cipher/Serpent.pm
+++ b/lib/Crypt/Cipher/Serpent.pm
@@ -21,7 +21,7 @@ sub default_rounds { Crypt::Cipher::defa
 
 =head1 NAME
 
-Crypt::Cipher::Serpent - Symetric cipher Serpent, key size: 128/192/256 bits (Crypt::CBC compliant)
+Crypt::Cipher::Serpent - Symmetric cipher Serpent, key size: 128/192/256 bits (Crypt::CBC compliant)
 
 =head1 SYNOPSIS
 
@@ -118,4 +118,4 @@ L<Crypt::Mode::CBC|Crypt::Mode::CBC>, L<
 
 =cut
 
-__END__
\ No newline at end of file
+__END__
--- a/lib/Crypt/Cipher.pm
+++ b/lib/Crypt/Cipher.pm
@@ -129,7 +129,7 @@ Crypt::Cipher - Generic interface to cip
 
 =head1 DESCRIPTION
 
-Provides an interface to various symetric cipher algorithms.
+Provides an interface to various symmetric cipher algorithms.
 
 B<BEWARE:> This module implements just elementary "one-block-(en|de)cryption" operation - if you want to
 encrypt/decrypt generic data you have to use some of the cipher block modes - check for example
@@ -150,7 +150,7 @@ Constructor, returns a reference to the
  #                simply any <NAME> for which there exists Crypt::Cipher::<NAME>
  # $key = binary key (keysize should comply with selected cipher requirements)
 
  ## some of the ciphers (e.g. MULTI2, RC5, SAFER) allows to set number of rounds
  $d = Crypt::Cipher->new('MULTI2', $key, $rounds);
  # $rounds = positive integer (should comply with selected cipher requirements)
 
@@ -202,7 +202,7 @@ Returns block size (in bytes) for given
 
 =head2 default_rounds
 
-Returns default number of rounds for given cipher. NOTE: only some cipher (e.g. MULTI2, RC5, SAFER) allows to set number of rounds via new().
+Returns default number of rounds for given cipher. NOTE: only some ciphers (e.g. MULTI2, RC5, SAFER) allow one to set number of rounds via new().
 
  $d->default_rounds;
  #or
@@ -150,7 +150,7 @@ Constructor, returns a reference to the
  # $key = binary key (keysize should comply with selected cipher requirements)
 
- ## some of the ciphers (e.g. MULTI2, RC5, SAFER) allows to set number of rounds
+ ## some of the ciphers (e.g. MULTI2, RC5, SAFER) allow one to set number of rounds
  $d = Crypt::Cipher->new('MULTI2', $key, $rounds);
  # $rounds = positive integer (should comply with selected cipher requirements)